# Utils

Utilities, complementing the Python Standard Library

[https://pypi.org/project/utils-nuuuwan](https://pypi.org/project/utils-nuuuwan)

## Setup & Install

```[bash]
pip install utils-nuuuwan
```

## Implementation Details

This library is a aggregation of the following libraries

* [utils_base](https://pypi.org/project/utils_base-nuuuwan/)
* [utils_git](https://pypi.org/project/utils_git-nuuuwan/)
* [utils_lang](https://pypi.org/project/utils_lang-nuuuwan/)
* [utils_twitter](https://pypi.org/project/utils_twitter-nuuuwan/)
* [utils_www](https://pypi.org/project/utils_www-nuuuwan/)
* [utils_ai](https://pypi.org/project/utils_ai-nuuuwan/)

## Recent Version History

### 2.0.11 (CURRENT)

* Removed tests

### 2.0.10

* Replaced modules with wildcards

### 2.0.9

* Make compatible with utils_base-nuuuwan==1.0.8

### 2.0.8

* utils_ai-nuuuwan==1.0.0

### 2.0.7

* utils_lang-nuuuwan==1.0.1

### 2.0.6

* utils_base-nuuuwan==1.0.4
